@@ -2,7 +2,7 @@
 #![no_main]
 
 use bsp::hal;
-use itsybitsy_m0 as bsp;
+use itsybitsy_m4 as bsp;
 
 #[cfg(not(feature = "use_semihosting"))]
 use panic_halt as _;
@@ -14,6 +14,7 @@ use hal::clock::GenericClockController;
 use hal::delay::Delay;
 use hal::pac::{CorePeripherals, Peripherals};
 use hal::prelude::*;
+use hal::watchdog::{Watchdog, WatchdogTimeout};
 
 #[entry]
 fn main() -> ! {
@@ -21,17 +22,26 @@ fn main() -> ! {
     let core = CorePeripherals::take().unwrap();
     let mut clocks = GenericClockController::with_internal_32kosc(
         peripherals.GCLK,
-        &mut peripherals.PM,
-        &mut peripherals.SYSCTRL,
+        &mut peripherals.MCLK,
+        &mut peripherals.OSC32KCTRL,
+        &mut peripherals.OSCCTRL,
         &mut peripherals.NVMCTRL,
     );
+    let mut delay = Delay::new(core.SYST, &mut clocks);
+    delay.delay_ms(400u16);
+
     let mut pins = bsp::Pins::new(peripherals.PORT);
     let mut red_led = pins.d13.into_open_drain_output(&mut pins.port);
-    let mut delay = Delay::new(core.SYST, &mut clocks);
+
+    let mut wdt = Watchdog::new(peripherals.WDT);
+    wdt.start(WatchdogTimeout::Cycles256 as u8);
+
     loop {
         delay.delay_ms(200u8);
+        wdt.feed();
         red_led.set_high().unwrap();
         delay.delay_ms(200u8);
+        wdt.feed();
         red_led.set_low().unwrap();
     }
 }
